<?php

namespace filebase\form;

use filebase\data\license\License;
use filebase\data\license\UserLicenseAction;
use wcf\form\AbstractForm;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\message\quote\MessageQuoteManager;
use wcf\system\WCF;

class UserLicenseEditForm extends UserLicenseAddForm {
	/**
	 * license id
	 * @var	integer
	 */
	public $licenseID = 0;
	
	/**
	 * license object
	 * @var	License
	 */
	public $license;
	
	/**
	 * @inheritDoc
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->licenseID = intval($_REQUEST['id']);
		$this->license = new License($this->licenseID);
		if (!$this->license->licenseID) {
			throw new IllegalLinkException();
		}
		if ($this->license->userID != WCF::getUser()->userID) {
			throw new PermissionDeniedException();
		}
	}
	
	/**
	 * @inheritDoc
	 */
	public function save() {
		AbstractForm::save();
		
		// update license
		$this->objectAction = new UserLicenseAction([$this->license], 'update', [
			'data' => array_merge($this->additionalFields, [
				'licenseName' => $this->licenseName,
				'licenseText' => $this->licenseText
			]),
			'htmlInputProcessor' => $this->htmlInputProcessor
		]);
		$this->objectAction->executeAction();
		$this->saved();
		MessageQuoteManager::getInstance()->saved();
		
		// show success message
		WCF::getTPL()->assign('success', true);
	}
	
	/**
	 * @inheritDoc
	 */
	public function readData() {
		parent::readData();
		
		if (empty($_POST)) {
			$this->licenseName = $this->license->licenseName;
			$this->licenseURL = $this->license->licenseURL;
			$this->licenseText = $this->license->licenseText;
		}
	}
	
	/**
	 * @inheritDoc
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign([
			'action' => 'edit',
			'licenseID' => $this->licenseID,
			'license' => $this->license
		]);
	}
}
